
//+------------------------------------------------------------------+
//|                                                      |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Copyright 2014 BY V.1 "
#property link      ""

#property indicator_separate_window
#property indicator_buffers 2
#property indicator_color1  Red
#property indicator_color2  Green
#property indicator_width1  2
#property indicator_width2  2
#property indicator_minimum 0
#property indicator_maximum 1

extern string TMA1TimeFrame    = "Current time frame";
extern string s0               = "TMA1 Settings";
extern int    TMA1HalfLength   = 20;
extern double TMA1K            = 2.5;
extern bool   alertsOn         = false;
extern bool   alertsOnCurrent  = true;
extern bool   alertsMessage    = true;
extern bool   alertsSound      = false;
extern bool   alertsEmail      = false;
extern bool   alertsNotify     = false;
extern string soundFile        = "alert.wav";
extern bool   ShowArrows       = false;
extern string arrowsIdentifier = "v1 Arrows1";
extern double arrowsUpperGap   = 1.0;
extern double arrowsLowerGap   = 1.0;
extern color  arrowsUpColor    = LimeGreen;
extern color  arrowsDnColor    = Red;
extern int    arrowsUpCode     = 241;
extern int    arrowsDnCode     = 242;
extern int    arrowsSize       = 1;




double BuyBuffer[];
double SEllBuffer[];
double trend[];
int    timeFrame;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
   IndicatorBuffers(3);
   SetIndexBuffer(0,BuyBuffer);  SetIndexStyle(0,DRAW_HISTOGRAM);
   SetIndexBuffer(1,SEllBuffer); SetIndexStyle(1,DRAW_HISTOGRAM);
   SetIndexBuffer(2,trend);
   
   timeFrame = stringToTimeFrame(TMA1TimeFrame);
   IndicatorShortName(timeFrameToString(timeFrame)+" V,1");
   SetIndexLabel(0,"");
   SetIndexLabel(1,"");
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit() 
{  
   deleteArrows(); 
return(0); 
}
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
   int counted_bars=IndicatorCounted();
      if(counted_bars<0) return(-1);
      if(counted_bars>0) counted_bars--;
            int limit=MathMax(Bars-counted_bars,3*timeFrame/Period());
            
   //
   //
   //
   //
   //
   
   for(int i=limit; i>=0; i--) 
   {
      int y = iBarShift(NULL, timeFrame,Time[i]);
      double TMA1 = iMA(NULL, timeFrame,TMA1HalfLength+1,0,3,0,y);
      double avg  = iATR(NULL,timeFrame,100,y+10);
      double upper = TMA1 + TMA1K*avg;
      double lower = TMA1 - TMA1K*avg;
      
      //
      //
      //
      //
      
      SEllBuffer[i] = EMPTY_VALUE;
      BuyBuffer[i]  = EMPTY_VALUE;
      trend[i] = 0;
      
      if(High[i]>upper) trend[i] =-1;
      if(Low[i] <lower) trend[i] = 1;
      if(trend[i] == 1) BuyBuffer[i]  = 1; 
      if(trend[i] ==-1) SEllBuffer[i] = 1; 
      
      //
      //
      //
      //
      //
      
      if (ShowArrows)
      {
         deleteArrow(Time[i]);
         if (trend[i] != trend[i+1])
         {
           if (trend[i] == 1)  drawArrow(i,arrowsDnColor,arrowsDnCode, true);
           if (trend[i] ==-1)  drawArrow(i,arrowsUpColor,arrowsUpCode,false);
         }
       }
   }
   
   //
   //
   //
   //
   //
     
    if (alertsOn)
    {
      if (alertsOnCurrent)
           int whichBar = 0;
      else     whichBar = 1; whichBar = iBarShift(NULL,0,iTime(NULL,timeFrame,whichBar));
      if (trend[whichBar] != trend[whichBar+1])
      if (trend[whichBar] == 1)
            doAlert("Sell");
      else  doAlert("Buy");       
   }             
return(0);
}

//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  StringConcatenate(Symbol()," ",timeFrameToString(timeFrame)," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," BY V.1 ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsNotify)  SendNotification(message);
             if (alertsEmail)   SendMail(StringConcatenate(Symbol()," BY V.1 "),message);
             if (alertsSound)   PlaySound(soundFile);
      }
}

//
//
//
//
//

void drawArrow(int i,color theColor,int theCode,bool up)
{
   string name = arrowsIdentifier+":"+Time[i];
   double gap  = iATR(NULL,0,20,i);   
   
      //
      //
      //
      //
      //
      
      ObjectCreate(name,OBJ_ARROW,0,Time[i],0);
         ObjectSet(name,OBJPROP_ARROWCODE,theCode);
         ObjectSet(name,OBJPROP_COLOR,theColor);
         ObjectSet(name,OBJPROP_WIDTH,arrowsSize);
         if (up)
               ObjectSet(name,OBJPROP_PRICE1,High[i] + arrowsUpperGap * gap);
         else  ObjectSet(name,OBJPROP_PRICE1,Low[i]  - arrowsLowerGap * gap);
}

//
//
//
//
//

void deleteArrows()
{
   string lookFor       = arrowsIdentifier+":";
   int    lookForLength = StringLen(lookFor);
   for (int i=ObjectsTotal()-1; i>=0; i--)
   {
      string objectName = ObjectName(i);
         if (StringSubstr(objectName,0,lookForLength) == lookFor) ObjectDelete(objectName);
   }
}

//
//
//
//
//

void deleteArrow(datetime time)
{
   string lookFor = arrowsIdentifier+":"+time; ObjectDelete(lookFor);
}

//+-------------------------------------------------------------------
//|                                                                  
//+-------------------------------------------------------------------
//
//
//
//
//

string sTfTable[] = {"M1","M5","M15","M30","H1","H4","D1","W1","MN"};
int    iTfTable[] = {1,5,15,30,60,240,1440,10080,43200};

//
//
//
//
//

int stringToTimeFrame(string tfs)
{
   tfs = stringUpperCase(tfs);
   for (int i=ArraySize(iTfTable)-1; i>=0; i--)
         if (tfs==sTfTable[i] || tfs==""+iTfTable[i]) return(MathMax(iTfTable[i],Period()));
                                                      return(Period());
}

//
//
//
//
//

string timeFrameToString(int tf)
{
   for (int i=ArraySize(iTfTable)-1; i>=0; i--) 
         if (tf==iTfTable[i]) return(sTfTable[i]);
                              return("");
}

//
//
//
//
//

string stringUpperCase(string str)
{
   string   s = str;

   for (int length=StringLen(str)-1; length>=0; length--)
   {
      int tchar = StringGetChar(s, length);
         if((tchar > 96 && tchar < 123) || (tchar > 223 && tchar < 256))
                     s = StringSetChar(s, length, tchar - 32);
         else if(tchar > -33 && tchar < 0)
                     s = StringSetChar(s, length, tchar + 224);
   }
   return(s);
}





